@@ -1,6 +1,8 @@
 """Module with other small functions"""
 from __future__ import print_function
 #  Standard library imports
+from math import floor
+from math import log10
 
 # Third party imports
 
@@ -31,3 +33,21 @@ def timedelta_nice_format(td_object):
             strings.append("%s %s%s" % (period_value, period_name, has_s))
 
     return ", ".join(strings)
+
+
+def rtnsd(float_num, int_digits=1):
+    """[summary]
+    Args:
+        float_num (float): float number to round
+        int_digits (int): How many significant digits you need. Defaults to 1.
+    """
+    if not isinstance(float_num, (float, int)):
+        raise TypeError("Unable to round number with type %s " % (
+            str(type(float_num))
+        ))
+
+
+    if not float_num:
+        return 0.0
+    int_sign_digits = floor(log10(abs(float_num)))
+    return round(float_num, int_digits - int(int_sign_digits) - 1)
